@@ -1,14 +1,13 @@
 from .servicelocation import SmappeeServiceLocation
 
 
-class Smappee(object):
+class Smappee:
 
     def __init__(self, api, serialnumber=None):
         """
         :param api:
         :param serialNumber:
         """
-
         # shared api instance
         self.smappee_api = api
 
@@ -55,4 +54,3 @@ class Smappee(object):
     def update_trends_and_appliance_states(self):
         for _, sl in self.service_locations.items():
             sl.update_trends_and_appliance_states()
-
